@@ -7,12 +7,12 @@ class FileSignatures:
     def __init__(self):
         path = "Data/file_signatures.json"
         fullpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), path)
-        with open(fullpath, "r", encoding="utf8", errors="ignore") as myfile:
+        with open(fullpath, "rb") as myfile:
             self.file_sigs = json.load(myfile)
 
     def open_file_loc(self, file_loc):
-        with open(file_loc, "r", encoding="utf8", errors="ignore") as myfile:
-            r = myfile.readlines()
+        with open(file_loc, "r", encoding="utf-8", errors="ignore") as myfile:
+            r = [myfile.read()]
         return r
 
     def open_binary_scan_magic_nums(self, file_loc):
