@@ -4,7 +4,7 @@ import click
 from rich.console import Console
 
 from pywhat import identifier, printer
-from pywhat.distribution import Distribution
+from pywhat.filter import Distribution, Filter
 from pywhat.helper import AvailableTags, InvalidTag, Keys, str_to_key
 
 
@@ -16,8 +16,8 @@ def print_tags(ctx, opts, value):
         sys.exit()
 
 
-def parse_options(rarity, include_tags, exclude_tags):
-    filter = dict()
+def create_filter(rarity, include, exclude):
+    filters_dict = dict()
     if rarity is not None:
         rarities = rarity.split(":")
         if len(rarities) != 2:
@@ -25,19 +25,19 @@ def parse_options(rarity, include_tags, exclude_tags):
             sys.exit(1)
         try:
             if not rarities[0].isspace() and rarities[0]:
-                filter["MinRarity"] = float(rarities[0])
+                filters_dict["MinRarity"] = float(rarities[0])
             if not rarities[1].isspace() and rarities[1]:
-                filter["MaxRarity"] = float(rarities[1])
+                filters_dict["MaxRarity"] = float(rarities[1])
         except ValueError:
             print("Invalid rarity argument (float expected)")
             sys.exit(1)
-    if include_tags is not None:
-        filter["Tags"] = list(map(str.strip, include_tags.split(",")))
-    if exclude_tags is not None:
-        filter["ExcludeTags"] = list(map(str.strip, exclude_tags.split(",")))
+    if include is not None:
+        filters_dict["Tags"] = list(map(str.strip, include.split(",")))
+    if exclude is not None:
+        filters_dict["ExcludeTags"] = list(map(str.strip, exclude.split(",")))
 
     try:
-        distribution = Distribution(filter)
+        filter = Filter(filters_dict)
     except InvalidTag:
         print(
             "Passed tags are not valid.\n"
@@ -45,7 +45,7 @@ def parse_options(rarity, include_tags, exclude_tags):
         )
         sys.exit(1)
 
-    return distribution
+    return filter
 
 
 @click.command(
@@ -68,29 +68,52 @@ def parse_options(rarity, include_tags, exclude_tags):
     help="Filter by rarity. Rarity is how unlikely something is to be a false-positive. The higher the number, the more unlikely. This is in the range of 0:1. To filter only items past 0.5, use 0.5: with the colon on the end. Default 0.1:1",
     default="0.1:1",
 )
-@click.option("-i", "--include_tags", help="Only print entries with included tags.")
-@click.option("-e", "--exclude_tags", help="Exclude tags.")
+@click.option("-i", "--include", help="Only show matches with these tags.")
+@click.option("-e", "--exclude", help="Disclude matches with these tags.")
 @click.option("-o", "--only-text", is_flag=True, help="Do not scan files or folders.")
 @click.option("-k", "--key", help="Sort by the specified key.")
 @click.option("--reverse", is_flag=True, help="Sort in reverse order.")
+@click.option(
+    "-br",
+    "--boundaryless-rarity",
+    help="Same as --rarity but for boundaryless mode (toggles what regexes will not have boundaries).",
+    default="0.1:1",
+)
+@click.option(
+    "-bi", "--boundaryless-include", help="Same as --include but for boundaryless mode."
+)
+@click.option(
+    "-be", "--boundaryless-exclude", help="Same as --exclude but for boundaryless mode."
+)
+@click.option(
+    "-db", "--disable-boundaryless", is_flag=True, help="Disable boundaryless mode."
+)
 @click.option("--json", is_flag=True, help="Return results in json format.")
-def main(text_input, rarity, include_tags, exclude_tags, only_text, key, reverse, json):
+def main(**kwargs):
     """
-    pyWhat - Identify what something is.\n
+    pyWhat - Identify what something is.
 
-    Made by Bee https://twitter.com/bee_sec_san\n
+    Made by Bee https://twitter.com/bee_sec_san
 
-    https://github.com/bee-san\n
+    https://github.com/bee-san
 
-    Filtration:\n
-        --rarity min:max\n
-            Rarity is how unlikely something is to be a false-positive. The higher the number, the more unlikely.\n
-            Only print entries with rarity in range [min,max]. min and max can be omitted.\n
-            Note: PyWhat by default has a rarity of 0.1. To see all matches, with many potential false positives use `0:`.\n
-        --include_tags list\n
-            Only include entries containing at least one tag in a list. List is a comma separated list.\n
-        --exclude_tags list\n
-            Exclude specified tags. List is a comma separated list.\n
+    Filtration:
+
+        --rarity min:max
+
+            Rarity is how unlikely something is to be a false-positive. The higher the number, the more unlikely.
+
+            Only print entries with rarity in range [min,max]. min and max can be omitted.
+
+            Note: PyWhat by default has a rarity of 0.1. To see all matches, with many potential false positives use `0:`.
+
+        --include list
+
+            Only include entries containing at least one tag in a list. List is a comma separated list.
+
+        --exclude list
+
+            Exclude specified tags. List is a comma separated list.
 
     Sorting:
 
@@ -118,6 +141,18 @@ def main(text_input, rarity, include_tags, exclude_tags, only_text, key, reverse
 
             Return results in json format.
 
+    Boundaryless mode:
+
+        CLI tool matches strings like 'abcdTHM{hello}plze' by default because the boundaryless mode is enabled for regexes with a rarity of 0.1 and higher.
+
+        Since boundaryless mode may produce a lot of false-positive matches, it is possible to disable it, either fully or partially.
+
+        '--disable-boundaryless' flag can be used to fully disable this mode.
+
+        In addition, '-br', '-bi', and '-be' options can be used to tweak which regexes should be in boundaryless mode.
+
+        Refer to the Filtration section for more information.
+
 
     Examples:
 
@@ -129,7 +164,9 @@ def main(text_input, rarity, include_tags, exclude_tags, only_text, key, reverse
 
         * what --rarity 0.6: 'myEmail@host.org'
 
-        * what --rarity 0: --include_tags "credentials, username, password" --exclude_tags "aws, credentials" 'James:SecretPassword'
+        * what --rarity 0: --include "credentials, username, password" --exclude "aws, credentials" 'James:SecretPassword'
+
+        * what -br 0.6: -be URL '123myEmail@host.org456'
 
     Your text must either be in quotation marks, or use the POSIX standard of "--" to mean "anything after -- is textual input".
 
@@ -141,36 +178,56 @@ def main(text_input, rarity, include_tags, exclude_tags, only_text, key, reverse
         * what 'this/is/a/path'
 
     """
-
-    what_obj = What_Object(parse_options(rarity, include_tags, exclude_tags))
-    if key is None:
+    dist = Distribution(
+        create_filter(kwargs["rarity"], kwargs["include"], kwargs["exclude"])
+    )
+    if kwargs["disable_boundaryless"]:
+        boundaryless = Filter({"Tags": []})  # use empty filter
+    else:
+        boundaryless = create_filter(
+            kwargs["boundaryless_rarity"],
+            kwargs["boundaryless_include"],
+            kwargs["boundaryless_exclude"],
+        )
+    what_obj = What_Object(dist)
+    if kwargs["key"] is None:
         key = Keys.NONE
     else:
         try:
-            key = str_to_key(key)
+            key = str_to_key(kwargs["key"])
         except ValueError:
             print("Invalid key")
             sys.exit(1)
-    identified_output = what_obj.what_is_this(text_input, only_text, key, reverse)
+    identified_output = what_obj.what_is_this(
+        kwargs["text_input"], kwargs["only_text"], key, kwargs["reverse"], boundaryless
+    )
 
     p = printer.Printing()
 
-    if json:
+    if kwargs["json"]:
         p.print_json(identified_output)
 
     else:
-        p.pretty_print(identified_output, text_input)
+        p.pretty_print(identified_output, kwargs["text_input"])
 
 
 class What_Object:
     def __init__(self, distribution):
         self.id = identifier.Identifier(dist=distribution)
 
-    def what_is_this(self, text: str, only_text: bool, key, reverse) -> dict:
+    def what_is_this(
+        self, text: str, only_text: bool, key, reverse: bool, boundaryless: Filter
+    ) -> dict:
         """
         Returns a Python dictionary of everything that has been identified
         """
-        return self.id.identify(text, only_text=only_text, key=key, reverse=reverse)
+        return self.id.identify(
+            text,
+            only_text=only_text,
+            key=key,
+            reverse=reverse,
+            boundaryless=boundaryless,
+        )
 
 
 if __name__ == "__main__":
